@@ -2,13 +2,14 @@ import datetime
 import logging
 from multiprocessing import Process, Queue
 import os
+from pathlib import Path
 import time
 
 import yaml
 from minio import Minio
 from minio.error import MinioException
 from pythonjsonlogger import jsonlogger
-from telegraf.client import TelegrafClient
+from influx_line_protocol import Metric
 
 logger = logging.getLogger()
 
@@ -45,13 +46,29 @@ CAMERA_EXPOSURE_MODE = os.environ.get("CAMERA_EXPOSURE_MODE", 'sports')
 CAMERA_SHUTTER_SPEED = int(os.environ.get("CAMERA_SHUTTER_SPEED", 0))
 CAMERA_H_FLIP = os.environ.get("CAMERA_H_FLIP", 0)
 CAMERA_V_FLIP = os.environ.get("CAMERA_V_FLIP", 0)
+METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "/var/log/wf_metrics"))
 
-TELEGRAF_HOST = os.environ.get("TELEGRAF_HOST", 'localhost')
+def get_logger(name):
+    logger = logging.getLogger("wf_metrics")
+    METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "./wf_metrics"))
+    if not METRICS_LOG_DIR.exists():
+        METRICS_LOG_DIR.mkdir()
+    path = METRICS_LOG_DIR / f"{name}.log"
+    logger.setLevel(logging.INFO)
+    handy = RotatingFileHandler(path, maxBytes=20000000, backupCount=5)
+    handy.setFormatter(logging.Formatter())
+    logger.addHandler(handy)
+    return logger
 
-
-def emit(name, values, tags=None):
-    client = TelegrafClient(host=TELEGRAF_HOST, port=8092)
+def emit(metlog, name, values, tags=None):
+    metric = Metric(name)
     client.metric(name, values, tags=tags)
+    metric.with_timestamp(time.time() * 1000000000)
+    for tag in tags:
+        metric.add_tag(tag, tags[tag])
+    for value in values:
+        metric.add_tag(value, values[value])
+    metlog.info(metric)
 
 
 def next_timeslot(now):
@@ -81,18 +98,18 @@ def capture_loop():
                 timeslot += PERIOD
             logger.info("going to sleep for a bit %s", sleep_time)
             time.sleep(sleep_time)
-            # camera.start_preview()
+            metlog = get_logger("capture_loop")
             video_start_time = datetime.datetime.fromtimestamp(timeslot)
             name = f'/out/video-{video_start_time:%Y_%m_%d_%H_%M-%S}.h264'
             camera.start_recording(name, format='h264', intra_period=INTRA_PERIOD, bitrate=BITRATE)
-            emit("camera_capture", {"video_start": 1, "origin": 1, "split": 0})
+            emit(metlog, "camera_capture", {"video_start": 1, "origin": 1, "split": 0})
             camera.wait_recording(PERIOD - 0.001)
             while True:
                 timeslot += PERIOD
                 video_start_time = datetime.datetime.fromtimestamp(timeslot)
                 name = f'/out/video-{video_start_time:%Y_%m_%d_%H_%M-%S}.h264'
                 logger.info("recording started", extra={"metric_tag": "video_start", "video_start_time": f"{video_start_time:%Y_%m_%d_%H_%M-%S}"})
-                emit("camera_capture", {"video_start": 1, "origin": 0, "split": 1})
+                emit(metlog, "camera_capture", {"video_start": 1, "origin": 0, "split": 1})
                 camera.split_recording(name, format='h264', intra_period=INTRA_PERIOD, bitrate=BITRATE)
                 delay = timeslot + PERIOD - time.time()
                 logger.info("waiting %s", delay)
@@ -138,6 +155,7 @@ def upload_loop():
         minioClient.make_bucket(BUCKET, location="us-east-1")
     except MinioException:
         pass
+    metlog = get_logger("upload_loop")
     while True:
         name = get_next_file()
         if name:
@@ -173,6 +191,6 @@ def upload_loop():
                 moved = 0
                 logger.exception(err)
                 logger.exception("failed to process %s", name)
-            emit("camera_move", {"ffmpeg_time_seconds": dur, "moved_to_control": moved})
+            emit(metlog, "camera_move", {"ffmpeg_time_seconds": dur, "moved_to_control": moved})
         else:
             time.sleep(2)
